@@ -24,17 +24,19 @@
 */
 
 #include <features.h>
-#ifdef __UCLIBC_HAVE_LFS__
+#ifdef __UCLIBC_HAS_LFS__
 #if defined _FILE_OFFSET_BITS && _FILE_OFFSET_BITS != 64 
 #undef _FILE_OFFSET_BITS
 #define	_FILE_OFFSET_BITS   64
 #endif
-#ifndef __USE_FILE_OFFSET64
-# define __USE_FILE_OFFSET64	1
-#endif
 #ifndef __USE_LARGEFILE64
 # define __USE_LARGEFILE64	1
 #endif
+/* We absolutely do _NOT_ want interfaces silently
+ * renamed under us or very bad things will happen... */
+#ifdef __USE_FILE_OFFSET64
+# undef __USE_FILE_OFFSET64
+#endif
 #include <dirent.h>
 #include <stdio.h>
 #include <string.h>
@@ -97,5 +99,5 @@ int scandir64(const char *dir, struct dirent64 ***namelist,
 
     return pos;
 }
-#endif /* __UCLIBC_HAVE_LFS__ */
+#endif /* __UCLIBC_HAS_LFS__ */
 
