@@ -27,6 +27,10 @@
 static struct pthread_key_struct pthread_keys[PTHREAD_KEYS_MAX] =
   { { 0, NULL } };
 
+/* For debugging purposes put the maximum number of keys in a variable.  */
+const int __linuxthreads_pthread_keys_max = PTHREAD_KEYS_MAX;
+const int __linuxthreads_pthread_key_2ndlevel_size = PTHREAD_KEY_2NDLEVEL_SIZE;
+
 /* Mutex to protect access to pthread_keys */
 
 static pthread_mutex_t pthread_keys_mutex = PTHREAD_MUTEX_INITIALIZER;
